Package com.google.cloud.workflows.v1
Class WorkflowsSettings
java.lang.Object
com.google.api.gax.rpc.ClientSettings<WorkflowsSettings>
com.google.cloud.workflows.v1.WorkflowsSettings
@Generated("by gapic-generator-java")
public class WorkflowsSettings
extends ClientSettings<WorkflowsSettings>
Settings class to configure an instance of
WorkflowsClient.
The default instance has everything set to sensible defaults:
- The default service address (workflows.googleapis.com) and default port (443) are used.
- Credentials are acquired automatically through Application Default Credentials.
- Retries are configured for idempotent methods but not for non-idempotent methods.
The builder of this class is recursive, so contained classes are themselves builders. When build() is called, the tree of builders is called to create the complete settings object.
For example, to set the [RetrySettings](https://cloud.google.com/java/docs/reference/gax/latest/com.google.api.gax.retrying.RetrySettings) of getWorkflow:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
WorkflowsSettings.Builder workflowsSettingsBuilder = WorkflowsSettings.newBuilder();
workflowsSettingsBuilder
.getWorkflowSettings()
.setRetrySettings(
workflowsSettingsBuilder
.getWorkflowSettings()
.getRetrySettings()
.toBuilder()
.setInitialRetryDelayDuration(Duration.ofSeconds(1))
.setInitialRpcTimeoutDuration(Duration.ofSeconds(5))
.setMaxAttempts(5)
.setMaxRetryDelayDuration(Duration.ofSeconds(30))
.setMaxRpcTimeoutDuration(Duration.ofSeconds(60))
.setRetryDelayMultiplier(1.3)
.setRpcTimeoutMultiplier(1.5)
.setTotalTimeoutDuration(Duration.ofSeconds(300))
.build());
WorkflowsSettings workflowsSettings = workflowsSettingsBuilder.build();
Please refer to the [Client Side Retry
Guide](https://docs.cloud.google.com/java/docs/client-retries) for additional support in setting
retries.
To configure the RetrySettings of a Long Running Operation method, create an OperationTimedPollAlgorithm object and update the RPC's polling algorithm. For example, to configure the RetrySettings for createWorkflow:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
WorkflowsSettings.Builder workflowsSettingsBuilder = WorkflowsSettings.newBuilder();
TimedRetryAlgorithm timedRetryAlgorithm =
OperationalTimedPollAlgorithm.create(
RetrySettings.newBuilder()
.setInitialRetryDelayDuration(Duration.ofMillis(500))
.setRetryDelayMultiplier(1.5)
.setMaxRetryDelayDuration(Duration.ofMillis(5000))
.setTotalTimeoutDuration(Duration.ofHours(24))
.build());
workflowsSettingsBuilder
.createClusterOperationSettings()
.setPollingAlgorithm(timedRetryAlgorithm)
.build();
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classBuilder for WorkflowsSettings. -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedWorkflowsSettings(WorkflowsSettings.Builder settingsBuilder) -
Method Summary
Modifier and TypeMethodDescriptionstatic final WorkflowsSettingscreate(WorkflowsStubSettings stub) Returns the object with the settings used for calls to createWorkflow.Returns the object with the settings used for calls to createWorkflow.Returns a builder for the default credentials for this service.Returns a builder for the default ExecutorProvider for this service.Returns a builder for the default gRPC ChannelProvider for this service.Returns a builder for the default REST ChannelProvider for this service.static TransportChannelProviderOperationCallSettings<DeleteWorkflowRequest,com.google.protobuf.Empty, OperationMetadata> Returns the object with the settings used for calls to deleteWorkflow.Returns the object with the settings used for calls to deleteWorkflow.static StringReturns the default service endpoint.Returns the default service scopes.Returns the object with the settings used for calls to getLocation.Returns the object with the settings used for calls to getWorkflow.PagedCallSettings<ListLocationsRequest,ListLocationsResponse, WorkflowsClient.ListLocationsPagedResponse> Returns the object with the settings used for calls to listLocations.PagedCallSettings<ListWorkflowRevisionsRequest,ListWorkflowRevisionsResponse, WorkflowsClient.ListWorkflowRevisionsPagedResponse> Returns the object with the settings used for calls to listWorkflowRevisions.PagedCallSettings<ListWorkflowsRequest,ListWorkflowsResponse, WorkflowsClient.ListWorkflowsPagedResponse> Returns the object with the settings used for calls to listWorkflows.static WorkflowsSettings.BuilderReturns a new gRPC builder for this class.static WorkflowsSettings.BuildernewBuilder(ClientContext clientContext) Returns a new builder for this class.static WorkflowsSettings.BuilderReturns a new REST builder for this class.Returns a builder containing all the values of this settings class.Returns the object with the settings used for calls to updateWorkflow.Returns the object with the settings used for calls to updateWorkflow.Methods inherited from class com.google.api.gax.rpc.ClientSettings
getApiKey, getBackgroundExecutorProvider, getClock, getCredentialsProvider, getEndpoint, getExecutorProvider, getGdchApiAudience, getHeaderProvider, getInternalHeaderProvider, getQuotaProjectId, getStubSettings, getTransportChannelProvider, getUniverseDomain, getWatchdogCheckInterval, getWatchdogCheckIntervalDuration, getWatchdogProvider, toString
-
Constructor Details
-
WorkflowsSettings
- Throws:
IOException
-
-
Method Details
-
listWorkflowsSettings
public PagedCallSettings<ListWorkflowsRequest,ListWorkflowsResponse, listWorkflowsSettings()WorkflowsClient.ListWorkflowsPagedResponse> Returns the object with the settings used for calls to listWorkflows. -
getWorkflowSettings
Returns the object with the settings used for calls to getWorkflow. -
createWorkflowSettings
Returns the object with the settings used for calls to createWorkflow. -
createWorkflowOperationSettings
public OperationCallSettings<CreateWorkflowRequest,Workflow, createWorkflowOperationSettings()OperationMetadata> Returns the object with the settings used for calls to createWorkflow. -
deleteWorkflowSettings
Returns the object with the settings used for calls to deleteWorkflow. -
deleteWorkflowOperationSettings
public OperationCallSettings<DeleteWorkflowRequest,com.google.protobuf.Empty, deleteWorkflowOperationSettings()OperationMetadata> Returns the object with the settings used for calls to deleteWorkflow. -
updateWorkflowSettings
Returns the object with the settings used for calls to updateWorkflow. -
updateWorkflowOperationSettings
public OperationCallSettings<UpdateWorkflowRequest,Workflow, updateWorkflowOperationSettings()OperationMetadata> Returns the object with the settings used for calls to updateWorkflow. -
listWorkflowRevisionsSettings
public PagedCallSettings<ListWorkflowRevisionsRequest,ListWorkflowRevisionsResponse, listWorkflowRevisionsSettings()WorkflowsClient.ListWorkflowRevisionsPagedResponse> Returns the object with the settings used for calls to listWorkflowRevisions. -
listLocationsSettings
public PagedCallSettings<ListLocationsRequest,ListLocationsResponse, listLocationsSettings()WorkflowsClient.ListLocationsPagedResponse> Returns the object with the settings used for calls to listLocations. -
getLocationSettings
Returns the object with the settings used for calls to getLocation. -
create
- Throws:
IOException
-
defaultExecutorProviderBuilder
Returns a builder for the default ExecutorProvider for this service. -
getDefaultEndpoint
Returns the default service endpoint. -
getDefaultServiceScopes
Returns the default service scopes. -
defaultCredentialsProviderBuilder
Returns a builder for the default credentials for this service. -
defaultGrpcTransportProviderBuilder
Returns a builder for the default gRPC ChannelProvider for this service. -
defaultHttpJsonTransportProviderBuilder
@BetaApi public static InstantiatingHttpJsonChannelProvider.Builder defaultHttpJsonTransportProviderBuilder()Returns a builder for the default REST ChannelProvider for this service. -
defaultTransportChannelProvider
-
defaultApiClientHeaderProviderBuilder
-
newBuilder
Returns a new gRPC builder for this class. -
newHttpJsonBuilder
Returns a new REST builder for this class. -
newBuilder
Returns a new builder for this class. -
toBuilder
Returns a builder containing all the values of this settings class.- Specified by:
toBuilderin classClientSettings<WorkflowsSettings>
-