Class WorkflowsClient
- All Implemented Interfaces:
BackgroundResource,AutoCloseable
This class provides the ability to make remote calls to the backing service through method calls that map to API methods. Sample code to get started:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
try (WorkflowsClient workflowsClient = WorkflowsClient.create()) {
WorkflowName name = WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]");
Workflow response = workflowsClient.getWorkflow(name);
}
Note: close() needs to be called on the WorkflowsClient object to clean up resources such as threads. In the example above, try-with-resources is used, which automatically calls close().
| Method | Description | Method Variants |
|---|---|---|
ListWorkflows |
Lists workflows in a given project and location. The default order is not specified. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
GetWorkflow |
Gets details of a single workflow. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
"Flattened" method variants have converted the fields of the request object into function parameters to enable multiple ways to call the same method.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
CreateWorkflow |
Creates a new workflow. If a workflow with the specified name already exists in the specified project and location, the long running operation returns a [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
Methods that return long-running operations have "Async" method variants that return `OperationFuture`, which is used to track polling of the service.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
DeleteWorkflow |
Deletes a workflow with the specified name. This method also cancels and deletes all running executions of the workflow. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
Methods that return long-running operations have "Async" method variants that return `OperationFuture`, which is used to track polling of the service.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
UpdateWorkflow |
Updates an existing workflow. Running this method has no impact on already running executions of the workflow. A new revision of the workflow might be created as a result of a successful update operation. In that case, the new revision is used in new workflow executions. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
Methods that return long-running operations have "Async" method variants that return `OperationFuture`, which is used to track polling of the service.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
ListWorkflowRevisions |
Lists revisions for a given workflow. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
ListLocations |
Lists information about the supported locations for this service. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
GetLocation |
Gets information about a location. |
Request object method variants only take one parameter, a request object, which must be constructed before the call.
Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.
|
See the individual methods for example code.
Many parameters require resource names to be formatted in a particular way. To assist with these names, this class includes a format method for each type of name, and additionally a parse method to extract the individual identifiers contained within names that are returned.
This class can be customized by passing in a custom instance of WorkflowsSettings to create(). For example:
To customize credentials:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
WorkflowsSettings workflowsSettings =
WorkflowsSettings.newBuilder()
.setCredentialsProvider(FixedCredentialsProvider.create(myCredentials))
.build();
WorkflowsClient workflowsClient = WorkflowsClient.create(workflowsSettings);
To customize the endpoint:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
WorkflowsSettings workflowsSettings =
WorkflowsSettings.newBuilder().setEndpoint(myEndpoint).build();
WorkflowsClient workflowsClient = WorkflowsClient.create(workflowsSettings);
To use REST (HTTP1.1/JSON) transport (instead of gRPC) for sending and receiving requests over the wire:
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in
// https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
WorkflowsSettings workflowsSettings = WorkflowsSettings.newHttpJsonBuilder().build();
WorkflowsClient workflowsClient = WorkflowsClient.create(workflowsSettings);
Please refer to the GitHub repository's samples for more quickstart code snippets.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic class -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedWorkflowsClient(WorkflowsStub stub) protectedWorkflowsClient(WorkflowsSettings settings) Constructs an instance of WorkflowsClient, using the given settings. -
Method Summary
Modifier and TypeMethodDescriptionbooleanawaitTermination(long duration, TimeUnit unit) final voidclose()static final WorkflowsClientcreate()Constructs an instance of WorkflowsClient with default settings.static final WorkflowsClientcreate(WorkflowsStub stub) Constructs an instance of WorkflowsClient, using the given stub for making calls.static final WorkflowsClientcreate(WorkflowsSettings settings) Constructs an instance of WorkflowsClient, using the given settings.createWorkflowAsync(CreateWorkflowRequest request) Creates a new workflow.createWorkflowAsync(LocationName parent, Workflow workflow, String workflowId) Creates a new workflow.createWorkflowAsync(String parent, Workflow workflow, String workflowId) Creates a new workflow.Creates a new workflow.Creates a new workflow.final OperationFuture<com.google.protobuf.Empty,OperationMetadata> deleteWorkflowAsync(DeleteWorkflowRequest request) Deletes a workflow with the specified name.final OperationFuture<com.google.protobuf.Empty,OperationMetadata> Deletes a workflow with the specified name.final OperationFuture<com.google.protobuf.Empty,OperationMetadata> deleteWorkflowAsync(String name) Deletes a workflow with the specified name.Deletes a workflow with the specified name.final OperationCallable<DeleteWorkflowRequest,com.google.protobuf.Empty, OperationMetadata> Deletes a workflow with the specified name.final OperationsClientReturns the OperationsClient that can be used to query the status of a long-running operation returned by another API method call.final LocationgetLocation(GetLocationRequest request) Gets information about a location.Gets information about a location.final OperationsClientReturns the OperationsClient that can be used to query the status of a long-running operation returned by another API method call.final WorkflowsSettingsgetStub()final WorkflowgetWorkflow(GetWorkflowRequest request) Gets details of a single workflow.final WorkflowgetWorkflow(WorkflowName name) Gets details of a single workflow.final WorkflowgetWorkflow(String name) Gets details of a single workflow.Gets details of a single workflow.booleanbooleanlistLocations(ListLocationsRequest request) Lists information about the supported locations for this service.Lists information about the supported locations for this service.Lists information about the supported locations for this service.Lists revisions for a given workflow.Lists revisions for a given workflow.final UnaryCallable<ListWorkflowRevisionsRequest,WorkflowsClient.ListWorkflowRevisionsPagedResponse> Lists revisions for a given workflow.listWorkflows(ListWorkflowsRequest request) Lists workflows in a given project and location.listWorkflows(LocationName parent) Lists workflows in a given project and location.listWorkflows(String parent) Lists workflows in a given project and location.Lists workflows in a given project and location.Lists workflows in a given project and location.voidshutdown()voidupdateWorkflowAsync(UpdateWorkflowRequest request) Updates an existing workflow.updateWorkflowAsync(Workflow workflow, com.google.protobuf.FieldMask updateMask) Updates an existing workflow.Updates an existing workflow.Updates an existing workflow.
-
Constructor Details
-
WorkflowsClient
Constructs an instance of WorkflowsClient, using the given settings. This is protected so that it is easy to make a subclass, but otherwise, the static factory methods should be preferred.- Throws:
IOException
-
WorkflowsClient
-
-
Method Details
-
create
Constructs an instance of WorkflowsClient with default settings.- Throws:
IOException
-
create
Constructs an instance of WorkflowsClient, using the given settings. The channels are created based on the settings passed in, or defaults for any settings that are not set.- Throws:
IOException
-
create
Constructs an instance of WorkflowsClient, using the given stub for making calls. This is for advanced usage - prefer using create(WorkflowsSettings). -
getSettings
-
getStub
-
getOperationsClient
Returns the OperationsClient that can be used to query the status of a long-running operation returned by another API method call. -
getHttpJsonOperationsClient
Returns the OperationsClient that can be used to query the status of a long-running operation returned by another API method call. -
listWorkflows
Lists workflows in a given project and location. The default order is not specified.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { LocationName parent = LocationName.of("[PROJECT]", "[LOCATION]"); for (Workflow element : workflowsClient.listWorkflows(parent).iterateAll()) { // doThingsWith(element); } }- Parameters:
parent- Required. Project and location from which the workflows should be listed. Format: projects/{project}/locations/{location}- Throws:
ApiException- if the remote call fails
-
listWorkflows
Lists workflows in a given project and location. The default order is not specified.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { String parent = LocationName.of("[PROJECT]", "[LOCATION]").toString(); for (Workflow element : workflowsClient.listWorkflows(parent).iterateAll()) { // doThingsWith(element); } }- Parameters:
parent- Required. Project and location from which the workflows should be listed. Format: projects/{project}/locations/{location}- Throws:
ApiException- if the remote call fails
-
listWorkflows
Lists workflows in a given project and location. The default order is not specified.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { ListWorkflowsRequest request = ListWorkflowsRequest.newBuilder() .setParent(LocationName.of("[PROJECT]", "[LOCATION]").toString()) .setPageSize(883849137) .setPageToken("pageToken873572522") .setFilter("filter-1274492040") .setOrderBy("orderBy-1207110587") .build(); for (Workflow element : workflowsClient.listWorkflows(request).iterateAll()) { // doThingsWith(element); } }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
listWorkflowsPagedCallable
public final UnaryCallable<ListWorkflowsRequest,WorkflowsClient.ListWorkflowsPagedResponse> listWorkflowsPagedCallable()Lists workflows in a given project and location. The default order is not specified.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { ListWorkflowsRequest request = ListWorkflowsRequest.newBuilder() .setParent(LocationName.of("[PROJECT]", "[LOCATION]").toString()) .setPageSize(883849137) .setPageToken("pageToken873572522") .setFilter("filter-1274492040") .setOrderBy("orderBy-1207110587") .build(); ApiFuture<Workflow> future = workflowsClient.listWorkflowsPagedCallable().futureCall(request); // Do something. for (Workflow element : future.get().iterateAll()) { // doThingsWith(element); } } -
listWorkflowsCallable
Lists workflows in a given project and location. The default order is not specified.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { ListWorkflowsRequest request = ListWorkflowsRequest.newBuilder() .setParent(LocationName.of("[PROJECT]", "[LOCATION]").toString()) .setPageSize(883849137) .setPageToken("pageToken873572522") .setFilter("filter-1274492040") .setOrderBy("orderBy-1207110587") .build(); while (true) { ListWorkflowsResponse response = workflowsClient.listWorkflowsCallable().call(request); for (Workflow element : response.getWorkflowsList()) { // doThingsWith(element); } String nextPageToken = response.getNextPageToken(); if (!Strings.isNullOrEmpty(nextPageToken)) { request = request.toBuilder().setPageToken(nextPageToken).build(); } else { break; } } } -
getWorkflow
Gets details of a single workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { WorkflowName name = WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]"); Workflow response = workflowsClient.getWorkflow(name); }- Parameters:
name- Required. Name of the workflow for which information should be retrieved. Format: projects/{project}/locations/{location}/workflows/{workflow}- Throws:
ApiException- if the remote call fails
-
getWorkflow
Gets details of a single workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { String name = WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]").toString(); Workflow response = workflowsClient.getWorkflow(name); }- Parameters:
name- Required. Name of the workflow for which information should be retrieved. Format: projects/{project}/locations/{location}/workflows/{workflow}- Throws:
ApiException- if the remote call fails
-
getWorkflow
Gets details of a single workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { GetWorkflowRequest request = GetWorkflowRequest.newBuilder() .setName(WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]").toString()) .setRevisionId("revisionId-1507445162") .build(); Workflow response = workflowsClient.getWorkflow(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
getWorkflowCallable
Gets details of a single workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { GetWorkflowRequest request = GetWorkflowRequest.newBuilder() .setName(WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]").toString()) .setRevisionId("revisionId-1507445162") .build(); ApiFuture<Workflow> future = workflowsClient.getWorkflowCallable().futureCall(request); // Do something. Workflow response = future.get(); } -
createWorkflowAsync
public final OperationFuture<Workflow,OperationMetadata> createWorkflowAsync(LocationName parent, Workflow workflow, String workflowId) Creates a new workflow. If a workflow with the specified name already exists in the specified project and location, the long running operation returns a [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { LocationName parent = LocationName.of("[PROJECT]", "[LOCATION]"); Workflow workflow = Workflow.newBuilder().build(); String workflowId = "workflowId-360387270"; Workflow response = workflowsClient.createWorkflowAsync(parent, workflow, workflowId).get(); }- Parameters:
parent- Required. Project and location in which the workflow should be created. Format: projects/{project}/locations/{location}workflow- Required. Workflow to be created.workflowId- Required. The ID of the workflow to be created. It has to fulfill the following requirements:- Must contain only letters, numbers, underscores and hyphens.
- Must start with a letter.
- Must be between 1-64 characters.
- Must end with a number or a letter.
- Must be unique within the customer project and location.
- Throws:
ApiException- if the remote call fails
-
createWorkflowAsync
public final OperationFuture<Workflow,OperationMetadata> createWorkflowAsync(String parent, Workflow workflow, String workflowId) Creates a new workflow. If a workflow with the specified name already exists in the specified project and location, the long running operation returns a [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { String parent = LocationName.of("[PROJECT]", "[LOCATION]").toString(); Workflow workflow = Workflow.newBuilder().build(); String workflowId = "workflowId-360387270"; Workflow response = workflowsClient.createWorkflowAsync(parent, workflow, workflowId).get(); }- Parameters:
parent- Required. Project and location in which the workflow should be created. Format: projects/{project}/locations/{location}workflow- Required. Workflow to be created.workflowId- Required. The ID of the workflow to be created. It has to fulfill the following requirements:- Must contain only letters, numbers, underscores and hyphens.
- Must start with a letter.
- Must be between 1-64 characters.
- Must end with a number or a letter.
- Must be unique within the customer project and location.
- Throws:
ApiException- if the remote call fails
-
createWorkflowAsync
public final OperationFuture<Workflow,OperationMetadata> createWorkflowAsync(CreateWorkflowRequest request) Creates a new workflow. If a workflow with the specified name already exists in the specified project and location, the long running operation returns a [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { CreateWorkflowRequest request = CreateWorkflowRequest.newBuilder() .setParent(LocationName.of("[PROJECT]", "[LOCATION]").toString()) .setWorkflow(Workflow.newBuilder().build()) .setWorkflowId("workflowId-360387270") .build(); Workflow response = workflowsClient.createWorkflowAsync(request).get(); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
createWorkflowOperationCallable
public final OperationCallable<CreateWorkflowRequest,Workflow, createWorkflowOperationCallable()OperationMetadata> Creates a new workflow. If a workflow with the specified name already exists in the specified project and location, the long running operation returns a [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { CreateWorkflowRequest request = CreateWorkflowRequest.newBuilder() .setParent(LocationName.of("[PROJECT]", "[LOCATION]").toString()) .setWorkflow(Workflow.newBuilder().build()) .setWorkflowId("workflowId-360387270") .build(); OperationFuture<Workflow, OperationMetadata> future = workflowsClient.createWorkflowOperationCallable().futureCall(request); // Do something. Workflow response = future.get(); } -
createWorkflowCallable
Creates a new workflow. If a workflow with the specified name already exists in the specified project and location, the long running operation returns a [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { CreateWorkflowRequest request = CreateWorkflowRequest.newBuilder() .setParent(LocationName.of("[PROJECT]", "[LOCATION]").toString()) .setWorkflow(Workflow.newBuilder().build()) .setWorkflowId("workflowId-360387270") .build(); ApiFuture<Operation> future = workflowsClient.createWorkflowCallable().futureCall(request); // Do something. Operation response = future.get(); } -
deleteWorkflowAsync
public final OperationFuture<com.google.protobuf.Empty,OperationMetadata> deleteWorkflowAsync(WorkflowName name) Deletes a workflow with the specified name. This method also cancels and deletes all running executions of the workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { WorkflowName name = WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]"); workflowsClient.deleteWorkflowAsync(name).get(); }- Parameters:
name- Required. Name of the workflow to be deleted. Format: projects/{project}/locations/{location}/workflows/{workflow}- Throws:
ApiException- if the remote call fails
-
deleteWorkflowAsync
public final OperationFuture<com.google.protobuf.Empty,OperationMetadata> deleteWorkflowAsync(String name) Deletes a workflow with the specified name. This method also cancels and deletes all running executions of the workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { String name = WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]").toString(); workflowsClient.deleteWorkflowAsync(name).get(); }- Parameters:
name- Required. Name of the workflow to be deleted. Format: projects/{project}/locations/{location}/workflows/{workflow}- Throws:
ApiException- if the remote call fails
-
deleteWorkflowAsync
public final OperationFuture<com.google.protobuf.Empty,OperationMetadata> deleteWorkflowAsync(DeleteWorkflowRequest request) Deletes a workflow with the specified name. This method also cancels and deletes all running executions of the workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { DeleteWorkflowRequest request = DeleteWorkflowRequest.newBuilder() .setName(WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]").toString()) .build(); workflowsClient.deleteWorkflowAsync(request).get(); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
deleteWorkflowOperationCallable
public final OperationCallable<DeleteWorkflowRequest,com.google.protobuf.Empty, deleteWorkflowOperationCallable()OperationMetadata> Deletes a workflow with the specified name. This method also cancels and deletes all running executions of the workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { DeleteWorkflowRequest request = DeleteWorkflowRequest.newBuilder() .setName(WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]").toString()) .build(); OperationFuture<Empty, OperationMetadata> future = workflowsClient.deleteWorkflowOperationCallable().futureCall(request); // Do something. future.get(); } -
deleteWorkflowCallable
Deletes a workflow with the specified name. This method also cancels and deletes all running executions of the workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { DeleteWorkflowRequest request = DeleteWorkflowRequest.newBuilder() .setName(WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]").toString()) .build(); ApiFuture<Operation> future = workflowsClient.deleteWorkflowCallable().futureCall(request); // Do something. future.get(); } -
updateWorkflowAsync
public final OperationFuture<Workflow,OperationMetadata> updateWorkflowAsync(Workflow workflow, com.google.protobuf.FieldMask updateMask) Updates an existing workflow. Running this method has no impact on already running executions of the workflow. A new revision of the workflow might be created as a result of a successful update operation. In that case, the new revision is used in new workflow executions.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { Workflow workflow = Workflow.newBuilder().build(); FieldMask updateMask = FieldMask.newBuilder().build(); Workflow response = workflowsClient.updateWorkflowAsync(workflow, updateMask).get(); }- Parameters:
workflow- Required. Workflow to be updated.updateMask- List of fields to be updated. If not present, the entire workflow will be updated.- Throws:
ApiException- if the remote call fails
-
updateWorkflowAsync
public final OperationFuture<Workflow,OperationMetadata> updateWorkflowAsync(UpdateWorkflowRequest request) Updates an existing workflow. Running this method has no impact on already running executions of the workflow. A new revision of the workflow might be created as a result of a successful update operation. In that case, the new revision is used in new workflow executions.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { UpdateWorkflowRequest request = UpdateWorkflowRequest.newBuilder() .setWorkflow(Workflow.newBuilder().build()) .setUpdateMask(FieldMask.newBuilder().build()) .build(); Workflow response = workflowsClient.updateWorkflowAsync(request).get(); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
updateWorkflowOperationCallable
public final OperationCallable<UpdateWorkflowRequest,Workflow, updateWorkflowOperationCallable()OperationMetadata> Updates an existing workflow. Running this method has no impact on already running executions of the workflow. A new revision of the workflow might be created as a result of a successful update operation. In that case, the new revision is used in new workflow executions.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { UpdateWorkflowRequest request = UpdateWorkflowRequest.newBuilder() .setWorkflow(Workflow.newBuilder().build()) .setUpdateMask(FieldMask.newBuilder().build()) .build(); OperationFuture<Workflow, OperationMetadata> future = workflowsClient.updateWorkflowOperationCallable().futureCall(request); // Do something. Workflow response = future.get(); } -
updateWorkflowCallable
Updates an existing workflow. Running this method has no impact on already running executions of the workflow. A new revision of the workflow might be created as a result of a successful update operation. In that case, the new revision is used in new workflow executions.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { UpdateWorkflowRequest request = UpdateWorkflowRequest.newBuilder() .setWorkflow(Workflow.newBuilder().build()) .setUpdateMask(FieldMask.newBuilder().build()) .build(); ApiFuture<Operation> future = workflowsClient.updateWorkflowCallable().futureCall(request); // Do something. Operation response = future.get(); } -
listWorkflowRevisions
public final WorkflowsClient.ListWorkflowRevisionsPagedResponse listWorkflowRevisions(ListWorkflowRevisionsRequest request) Lists revisions for a given workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { ListWorkflowRevisionsRequest request = ListWorkflowRevisionsRequest.newBuilder() .setName(WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]").toString()) .setPageSize(883849137) .setPageToken("pageToken873572522") .build(); for (Workflow element : workflowsClient.listWorkflowRevisions(request).iterateAll()) { // doThingsWith(element); } }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
listWorkflowRevisionsPagedCallable
public final UnaryCallable<ListWorkflowRevisionsRequest,WorkflowsClient.ListWorkflowRevisionsPagedResponse> listWorkflowRevisionsPagedCallable()Lists revisions for a given workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { ListWorkflowRevisionsRequest request = ListWorkflowRevisionsRequest.newBuilder() .setName(WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]").toString()) .setPageSize(883849137) .setPageToken("pageToken873572522") .build(); ApiFuture<Workflow> future = workflowsClient.listWorkflowRevisionsPagedCallable().futureCall(request); // Do something. for (Workflow element : future.get().iterateAll()) { // doThingsWith(element); } } -
listWorkflowRevisionsCallable
public final UnaryCallable<ListWorkflowRevisionsRequest,ListWorkflowRevisionsResponse> listWorkflowRevisionsCallable()Lists revisions for a given workflow.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { ListWorkflowRevisionsRequest request = ListWorkflowRevisionsRequest.newBuilder() .setName(WorkflowName.of("[PROJECT]", "[LOCATION]", "[WORKFLOW]").toString()) .setPageSize(883849137) .setPageToken("pageToken873572522") .build(); while (true) { ListWorkflowRevisionsResponse response = workflowsClient.listWorkflowRevisionsCallable().call(request); for (Workflow element : response.getWorkflowsList()) { // doThingsWith(element); } String nextPageToken = response.getNextPageToken(); if (!Strings.isNullOrEmpty(nextPageToken)) { request = request.toBuilder().setPageToken(nextPageToken).build(); } else { break; } } } -
listLocations
Lists information about the supported locations for this service.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { ListLocationsRequest request = ListLocationsRequest.newBuilder() .setName("name3373707") .setFilter("filter-1274492040") .setPageSize(883849137) .setPageToken("pageToken873572522") .build(); for (Location element : workflowsClient.listLocations(request).iterateAll()) { // doThingsWith(element); } }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
listLocationsPagedCallable
public final UnaryCallable<ListLocationsRequest,WorkflowsClient.ListLocationsPagedResponse> listLocationsPagedCallable()Lists information about the supported locations for this service.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { ListLocationsRequest request = ListLocationsRequest.newBuilder() .setName("name3373707") .setFilter("filter-1274492040") .setPageSize(883849137) .setPageToken("pageToken873572522") .build(); ApiFuture<Location> future = workflowsClient.listLocationsPagedCallable().futureCall(request); // Do something. for (Location element : future.get().iterateAll()) { // doThingsWith(element); } } -
listLocationsCallable
Lists information about the supported locations for this service.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { ListLocationsRequest request = ListLocationsRequest.newBuilder() .setName("name3373707") .setFilter("filter-1274492040") .setPageSize(883849137) .setPageToken("pageToken873572522") .build(); while (true) { ListLocationsResponse response = workflowsClient.listLocationsCallable().call(request); for (Location element : response.getLocationsList()) { // doThingsWith(element); } String nextPageToken = response.getNextPageToken(); if (!Strings.isNullOrEmpty(nextPageToken)) { request = request.toBuilder().setPageToken(nextPageToken).build(); } else { break; } } } -
getLocation
Gets information about a location.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { GetLocationRequest request = GetLocationRequest.newBuilder().setName("name3373707").build(); Location response = workflowsClient.getLocation(request); }- Parameters:
request- The request object containing all of the parameters for the API call.- Throws:
ApiException- if the remote call fails
-
getLocationCallable
Gets information about a location.Sample code:
// This snippet has been automatically generated and should be regarded as a code template only. // It will require modifications to work: // - It may require correct/in-range values for request initialization. // - It may require specifying regional endpoints when creating the service client as shown in // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library try (WorkflowsClient workflowsClient = WorkflowsClient.create()) { GetLocationRequest request = GetLocationRequest.newBuilder().setName("name3373707").build(); ApiFuture<Location> future = workflowsClient.getLocationCallable().futureCall(request); // Do something. Location response = future.get(); } -
close
public final void close()- Specified by:
closein interfaceAutoCloseable
-
shutdown
public void shutdown()- Specified by:
shutdownin interfaceBackgroundResource
-
isShutdown
public boolean isShutdown()- Specified by:
isShutdownin interfaceBackgroundResource
-
isTerminated
public boolean isTerminated()- Specified by:
isTerminatedin interfaceBackgroundResource
-
shutdownNow
public void shutdownNow()- Specified by:
shutdownNowin interfaceBackgroundResource
-
awaitTermination
- Specified by:
awaitTerminationin interfaceBackgroundResource- Throws:
InterruptedException
-